#	Copyright (C) QUADStor Systems
#	Copyright (C) Shivaram Upadhyayula <shivaram.u@quadstor.com>
#
"""
QUADStor Cinder Common
"""

from oslo.config import cfg
from cinder.volume.drivers.san.san import SanISCSIDriver

quadstor_opts = [
	cfg.StrOpt('vdisk_compression',
		   default='off',
		   help='Enable/Disable VDisk compression'),
	cfg.StrOpt('vdisk_pool',
		   default=None,
		   help='Storage pool for VDisks'),
	cfg.StrOpt('vdisk_deduplication',
		   default='on',
		   help='Enable/Disable VDisk deduplication'),
	cfg.StrOpt('vdisk_volume_prefix',
		   default='',
		   help='Prefix for VDisk names to identify that it is a cinder volume/snapshot'),
	]

def quadstor_iscsi_target_name(self, volume):
	volume_prefix = self.configuration.safe_get('vdisk_volume_prefix')
	iqn = "%s%s%s" % (self.configuration.iscsi_target_prefix, volume_prefix, volume['name'])
	return iqn

def quadstor_create_volume(self, volume):
	args = ["/quadstor/bin/vdconfig", "-a", "-e", "-v"]
	volume_prefix = self.configuration.safe_get('vdisk_volume_prefix')
	args.append("'%s%s'" % (volume_prefix, volume['name']))
	args.append('-s')
	if int(volume['size']) == 0:
		args.append('100')
	else:
		args.append("%s" % volume['size'])
	pool = self.configuration.safe_get('vdisk_pool')
	if pool:
		args.append('-g')
		args.append("'%s'" % pool)
	compression = self.configuration.safe_get('vdisk_compression')
	if compression and compression == 'on':
		args.append(" -c")
	dedupe = self.configuration.safe_get('vdisk_deduplication')
	if dedupe == None or dedupe != 'off':
		args.append(" -d")
	iqn = "%s%s%s" % (self.configuration.iscsi_target_prefix, volume_prefix, volume['name'])
	args.append("-i")
	args.append("'%s'" % iqn)
	cmd = ''.join(args)
	self._run_ssh(args)

def quadstor_delete_volume(self, name): 
	args = ["/quadstor/bin/vdconfig", "-x", "-f", "-v"]
	volume_prefix = self.configuration.safe_get('vdisk_volume_prefix')
	args.append("'%s%s'" % (volume_prefix, name))
	cmd = ''.join(args)
	self._run_ssh(args)

def quadstor_extend_volume(self, volume, new_size):
	args = ["/quadstor/bin/vdconfig", "-f", "-v"]
	volume_prefix = self.configuration.safe_get('vdisk_volume_prefix')
	args.append("'%s%s'" % (volume_prefix, volume['name']))
	args.append("-s")
	if int(new_size) == 0:
		raise exception.InvalidInput(reason=_("New size cannot be zero"))
	else:
		args.append("%s" % new_size)
	cmd = ''.join(args)
	self._run_ssh(args)

def quadstor_create_clone(self, src, dest):
	args = ["/quadstor/bin/qclone", "-w"]
	volume_prefix = self.configuration.safe_get('vdisk_volume_prefix')
	args.append("-s")
	args.append("'%s%s'" % (volume_prefix, src))
	args.append("-d")
	args.append("'%s%s'" % (volume_prefix, dest))
	cmd = ''.join(args)
	self._run_ssh(args)
